==> r-mail-1.0.0.zip: r-mail-1.0.0/gestion_messages/envoi_message.php <==
<?

session_start ();

if (isset ($envoi_mail) && empty ($destinataire)) {
$stop=1;
}

//---------------------------------------------------------------------------//
//Un grand merci au site tout est facile (http://www.toutestfacile.com/)
//qui explique la fabrication d'un message avec fichier joint au format mime
//pour les gros neuneus dbiles comme moi qui ne suis pas dveloppeur
//---------------------------------------------------------------------------//

if (isset ($envoi_mail) && !isset ($stop)) {

//----------------------------------
// Construction de l'entte
//----------------------------------
// On choisi gnralement de construire une frontire gnre aleatoirement
// comme suit. (REM: je n'en connais pas la raison profonde)
	
$boundary = "---R-MAIL-V.1.0.0---=".md5(uniqid(rand()));

// Ici, on construit un entte contenant les informations
// minimales requises.
//	Version du format MIME utilis
	
$header = "MIME-Version: 1.0\r\n";

//	Type de contenu. Ici plusieurs parties de type different "multipart/mixed"
//	Avec un frontire dfinie par $boundary

$header .= "Content-Type: multipart/mixed; boundary=\"$boundary\"\r\n";
$header .= "\r\n";

//--------------------------------------------------
// Construction du message proprement dit
//--------------------------------------------------
	
// Pour le cas, o le logiciel de mail du destinataire
// n'est pas capable de lire le format MIME de cette version
// Il est de bon ton de l'en informer
// REM: Ce message n'apparat pas pour les logiciels sachant lire ce format
	
$msg1 = "Je vous informe que ceci est un message au format MIME 1.0 multipart/mixed.\r\n";

//---------------------------------
// 1re partie du message
// Le texte
//---------------------------------
// Chaque partie du message est spar par une frontire
	
$msg1 .= "--$boundary\r\n";
	
// Et pour chaque partie on en indique le type
	
$msg1 .= "Content-Type: text/plain; charset=\"iso-8859-1\"\r\n";
	
// Et comment il sera cod
	
$msg1 .= "Content-Transfer-Encoding:8bit\r\n";
	
// Il est indispensable d'introduire une ligne vide entre l'entte et le texte

$msg1 .= "\r\n";
	
// Enfin, on peut crire le texte de la 1re partie
//$msg .= "Ceci est un mail avec un fichier joint\r\n";

$msg1 .= "$texte\r\n";
$msg1 .= "\r\n";
	
//---------------------------------
// 2nde partie du message
// Le fichier
//---------------------------------
	
//Vrification s'il y a pice jointe
	
$incr=0;

	if (@$rep=opendir("$temp_dir/$login")) {
	
		while ($file = readdir($rep)) {
			if ($file !="." && $file !="..") {
			$incr++;
			}
		}
	
	closedir($rep);
	}

	if ($incr>0) {

	include 'types_medias.php';

	//Rcupration du ou des nom(s) de fichier(s)
		
	//Traitement de chaque nom
		
		if (@$rep=opendir("$temp_dir/$login")) {
	
			while ($file = readdir($rep)) {
				if ($file !="." && $file !="..") {
			
				// On lit le contenu du fichier
					
				$fp = fopen("$temp_dir/$login/$file", "rb");
				$attachment = fread($fp, filesize("$temp_dir/$login/$file"));
				fclose($fp);
					
				// puis convertir le contenu du fichier en une chane de caractre
				// certe totalement illisible mais sans caractres exotiques
				// et avec des retours  la ligne tout les 76 caractres
				// pour tre conforme au format RFC 2045
			
				$attachment = chunk_split(base64_encode($attachment));
					
				// Ne pas oublier que chaque partie du message est spar par une frontire
					
				$msg2 .= "--$boundary\r\n";
					
				//Rcupration de l'extension du fichier
					
				$suppr=preg_split ("/[.]/", $file);
				preg_match_all ("/\w+.[^\"\\\]/", $suppr[1], $recup);
				
				$ext=$recup[0][0];
					
				// Et pour chaque partie on en indique le type
			
					if (isset ($types_medias[$ext])) {
					$msg2 .= "Content-Type: $types_medias[$ext]; name=\"$file\"\r\n";
					} else {
					$msg2 .= "Content-Type: application/unknown; name=\"$file\"\r\n";
					}

				// Et comment il sera cod
						
				$msg2 .= "Content-Transfer-Encoding: base64\r\n";
						
				// Petit plus pour les fichiers joints
				// Il est possible de demander  ce que le fichier
				// soit si possible affich dans le corps du mail
				//$msg .= "Content-Disposition: inline; filename=\"$file\"\r\n";
						
				$msg2 .= "Content-Disposition: attachment; filename=\"$file\"\r\n";
					
				// Il est indispensable d'introduire une ligne vide entre l'entte et le texte
						
				$msg2 .= "\r\n";
						
				// C'est ici que l'on insre le code du fichier lu
						
				$msg2 .= $attachment . "\r\n";
				$msg2 .= "\r\n\r\n";
		
				}
			}

		closedir($rep);
		}

	// voil, on indique la fin par une nouvelle frontire

	$msg3 .= "--$boundary--\r\n";

	$msg="$msg1$msg2$msg3";

		mail($destinataire, $sujet, $msg, "Reply-to: $repondre_a\r\nFrom: $expediteur\r\nCc: $copies\r\nBcc: $copies_cachees\r\n".$header);

		//Copie du mail dans la bote sent

		$serveur="{".$serveur_mail.":$port_connexion"."}";

		$stream=@imap_open($serveur,"$login","$password")
		or die ('impossible de se connecter au serveur');

		//Vrification de l'existence de la boite Sent Items

		$list=imap_listmailbox ($stream, "$serveur", "Sent Items");

		preg_match_all ("/[^$serveur][\s\w]+/", $list[0], $recup);

			if ($recup[0][0]!="Sent Items") {
			$boite="Sent Items";
				if (@imap_createmailbox ($stream,imap_utf7_encode("$serveur$boite"))===false) {
				$erreur=1;
				}
			}

		//Rcupration de la ou des pices jointes

		imap_append($stream,"{".$serveur_mail."}Sent Items"
		,"From: $expediteur\r\n"."To: $destinataire\r\n"."Subject: $sujet\r\n".
		"Cc: $copies\r\n"."Bcc: $copies_cachees\r\n"."Reply-To: $repondre_a\r\n".
		"$header"."\r\n"."$msg1\r\n"."$msg2\r\n"."$msg3\r\n");

		imap_close($stream);

			if (@$rep=opendir("$temp_dir/$login")) {

				while ($file=readdir($rep)) {
					if ($file !="." && $file !="..") {
						if (filesize ("$temp_dir/$login/$file")!=0) {
						unlink ("$temp_dir/$login/$file");
						$supr_rep=1;
						}
					}
				}
			}
		closedir($rep);

			if (isset ($supr_rep)) {
			@rmdir ("$temp_dir/$login");
			}

	} else {

		if (!@mail($destinataire, $sujet, $texte, "Reply-to: $repondre_a\r\nFrom: $expediteur\r\nCc: $copies\r\nBcc: $copies_cachees\r\n")) {
		$vide=1;
		}
	//Copie du mail dans la bote sent

	$serveur="{".$serveur_mail.":$port_connexion"."}";

	$stream=@imap_open($serveur,"$login","$password")
	or die ('impossible de se connecter au serveur');

	//Vrification de l'existence de la boite Sent Items

	$list=imap_listmailbox ($stream, "$serveur", "Sent Items");

	preg_match_all ("/[^$serveur][\s\w]+/", $list[0], $recup);

		if ($recup[0][0]!="Sent Items") {
		$boite="Sent Items";
			if (@imap_createmailbox ($stream,imap_utf7_encode("$serveur$boite"))===false) {
			$erreur=1;
			}
		}

	//Rcupration du message

	imap_append($stream,"{".$serveur_mail."}Sent Items"
	,"From: $expediteur\r\n"."To: $destinataire\r\n"."Subject: $sujet\r\n".
	"Cc: $copies\r\n"."Bcc: $copies_cachees\r\n"."Reply-To: $repondre_a\r\n".
	"\r\n"."$texte\r\n");

	imap_close($stream);
	}

}

?>

==> r-mail-1.0.2.zip: r-mail.1.0.2/gestion_messages/envoi_message.php <==
<?

//------------------------------------------------------------------------------//
//Merci au site tout est facile (http://www.toutestfacile.com/) pour la		//
//construction d'un message au format mime					//
//------------------------------------------------------------------------------//

include '../langage.php';

$temp_dir = $_SESSION ["temp_dir"];
$login = $_SESSION ["login"];

if (isset ($_POST ["envoi_mail"]) && empty ($_POST ["destinataire"])) {
$stop=1;
}

if (isset ($_POST ["envoi_mail"]) && !isset ($stop)) {

//----------------------------------
// Construction de l'entte
//----------------------------------
// On choisi gnralement de construire une frontire gnre aleatoirement
// comme suit.
	
$boundary = "---R-MAIL---=".md5(uniqid(rand()));

// 	Ici, on construit un entte contenant les informations
// 	minimales requises.
//	Version du format MIME utilis
	
$header = "MIME-Version: 1.0\r\n";

//	Type de contenu. Ici plusieurs parties de type different "multipart/mixed"
//	Avec un frontire dfinie par $boundary

$header .= "Content-Type: multipart/mixed; boundary=\"$boundary\"\r\n";
$header .= "\r\n";

//--------------------------------------------------
// Construction du message proprement dit
//--------------------------------------------------
	
// Pour le cas, o le logiciel de mail du destinataire
// n'est pas capable de lire le format MIME de cette version
// Il est de bon ton de l'en informer
// REM: Ce message n'apparat pas pour les logiciels sachant lire ce format
	
$msg1 = "Je vous informe que ceci est un message au format MIME 1.0 multipart/mixed.\r\n";

//---------------------------------
// 1re partie du message
// Le texte
//---------------------------------
// Chaque partie du message est spar par une frontire
	
$msg1 .= "--$boundary\r\n";
	
// Et pour chaque partie on en indique le type
	
$msg1 .= "Content-Type: text/plain; charset=\"iso-8859-1\"\r\n";
	
// Et comment il sera cod
	
$msg1 .= "Content-Transfer-Encoding:8bit\r\n";
	
// Il est indispensable d'introduire une ligne vide entre l'entte et le texte

$msg1 .= "\r\n";
	
// Enfin, on peut crire le texte de la 1re partie
//$msg .= "Ceci est un mail avec un fichier joint\r\n";

$msg1 .= $_POST ["texte"]."\r\n";
$msg1 .= "\r\n";

//---------------------------------
// 2nde partie du message
// Le fichier
//---------------------------------
	
//Vrification s'il y a pice jointe
	
$incr=0;

	if (@$rep=opendir("$temp_dir/$login")) {
	
		while ($file = readdir($rep)) {
			if ($file !="." && $file !="..") {
			$incr++;
			}
		}

	closedir($rep);
	}

	if ($incr>0) {

	include 'types_medias.php';

	//Rcupration du ou des nom(s) de fichier(s)
		
	//Traitement de chaque nom
	
		if (@$rep=opendir("$temp_dir/$login")) {
	
			while ($file = readdir($rep)) {
				if ($file !="." && $file !="..") {
			
				// On lit le contenu du fichier
					
				$fp = fopen("$temp_dir/$login/$file", "rb");
				$attachment = fread($fp, filesize("$temp_dir/$login/$file"));
				fclose($fp);
				
				// puis convertir le contenu du fichier en une chane de caractre
				// certe totalement illisible mais sans caractres exotiques
				// et avec des retours  la ligne tout les 76 caractres
				// pour tre conforme au format RFC 2045
			
				$attachment = chunk_split(base64_encode($attachment));

				// Ne pas oublier que chaque partie du message est spar par une frontire
					
				$msg2 = "--$boundary\r\n";
					
				//Rcupration de l'extension du fichier
					
				$suppr=preg_split ("/[.]/", $file);
				preg_match_all ("/\w+.[^\"\\\]/", $suppr[1], $recup);
				
				$ext=$recup[0][0];
					
				// Et pour chaque partie on en indique le type
			
					if (isset ($types_medias[$ext])) {
					$msg2 .= "Content-Type: $types_medias[$ext]; name=\"$file\"\r\n";
					} else {
					$msg2 .= "Content-Type: application/unknown; name=\"$file\"\r\n";
					}

				// Et comment il sera cod
						
				$msg2 .= "Content-Transfer-Encoding: base64\r\n";
						
				// Petit plus pour les fichiers joints
				// Il est possible de demander  ce que le fichier
				// soit si possible affich dans le corps du mail
				//$msg .= "Content-Disposition: inline; filename=\"$file\"\r\n";
						
				$msg2 .= "Content-Disposition: attachment; filename=\"$file\"\r\n";
							
				// Il est indispensable d'introduire une ligne vide entre l'entte et le texte
						
				$msg2 .= "\r\n";
						
				// C'est ici que l'on insre le code du fichier lu
						
				$msg2 .= $attachment . "\r\n";
				$msg2 .= "\r\n\r\n";

				}
			}

		closedir($rep);
		}

		// voil, on indique la fin par une nouvelle frontire
	
		$msg3 = "--$boundary--\r\n";
	
		$msg="$msg1$msg2$msg3";

		@mail($_POST ["destinataire"], $_POST ["sujet"], $msg, "From: ".$_POST ["expediteur"]."\r\nReply-to: ".$_POST ["repondre_a"]."\r\nCc: ".$_POST ["copies"]."\r\nBcc: ".$_POST ["copies_cachees"]."\r\n".$header);
	//	@mail($_POST ["destinataire"], $_POST ["sujet"], $msg, "From: ".$_POST ["expediteur"]."\r\nReply-to: ".$_POST ["repondre_a"]."\r\n".$header);
						
		//Copie du mail dans la bote sent

		$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}";

		$stream=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
		or die ($page_envoi_message[$lang]);

		//Vrification de l'existence de la boite Sent Items

		$list=imap_listmailbox ($stream, "$serveur", "Sent Items");

		preg_match_all ("/[^$serveur][\s\w]+/", $list[0], $recup);

			if ($recup[0][0]!="Sent Items") {
			$boite="Sent Items";
				if (@imap_createmailbox ($stream,imap_utf7_encode("$serveur$boite"))===false) {
				$erreur=1;
				}
			}

		//Rcupration de la ou des pices jointes

		imap_append($stream,"{".$_SESSION ["serveur_mail"]."}Sent Items"
		,"From: ".$_POST ["expediteur"]."\r\n"."To: ".$_POST ["destinataire"]."\r\n"."Subject: ".$_POST ["sujet"]."\r\n".
		"Cc: ".$_POST ["copies"]."\r\n"."Bcc: ".$_POST ["copies_cachees"]."\r\n"."Reply-To: ".$_POST ["repondre_a"]."\r\n".
		"$header"."\r\n"."$msg1\r\n"."$msg2\r\n"."$msg3\r\n");

		imap_close($stream);

			if (@$rep=opendir("$temp_dir/$login")) {

				while ($file=readdir($rep)) {
					if ($file !="." && $file !="..") {
						if (filesize ("$temp_dir/$login/$file")!=0) {
						unlink ("$temp_dir/$login/$file");
						$supr_rep=1;
						}
					}
				}
			}
		closedir($rep);

			if (isset ($supr_rep)) {
			@rmdir ("$temp_dir/$login");
			}

	} else {

		@mail($_POST ["destinataire"], $_POST ["sujet"], $_POST ["texte"], "From: ".$_POST ["expediteur"]."\r\nReply-to: ".$_POST ["repondre_a"]."\r\nCc: ".$_POST ["copies"]."\r\nBcc: ".$_POST ["copies_cachees"]."\r\n");
	//	@mail($_POST ["destinataire"], $_POST ["sujet"], $_POST ["texte"], "From: ".$_POST ["expediteur"]."\r\nReply-to: ".$_POST ["repondre_a"]."\r\n");
		
	//Copie du mail dans la bote sent

	$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}";

	$stream=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
	or die ($page_envoi_message[$lang]);

	//Vrification de l'existence de la boite Sent Items

	$list=imap_listmailbox ($stream, "$serveur", "Sent Items");

	preg_match_all ("/[^$serveur][\s\w]+/", $list[0], $recup);

		if ($recup[0][0]!="Sent Items") {
		$boite="Sent Items";
			if (@imap_createmailbox ($stream,imap_utf7_encode("$serveur$boite"))===false) {
			$erreur=1;
			}
		}

	//Rcupration du message

	imap_append($stream,"{".$_SESSION ["serveur_mail"]."}Sent Items"
	,"From: ".$_POST ["expediteur"]."\r\n"."To: ".$_POST ["destinataire"]."\r\n"."Subject: ".$_POST ["sujet"]."\r\n".
	"Cc: ".$_POST ["copies"]."\r\n"."Bcc: ".$_POST ["copies_cachees"]."\r\n"."Reply-To: ".$_POST ["repondre_a"]."\r\n".
	"\r\n".$_POST ["texte"]."\r\n");

	imap_close($stream);
	}

}

?>
